package com.example.tmap_test

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.ViewGroup.LayoutParams.MATCH_PARENT
import android.view.ViewGroup.LayoutParams.WRAP_CONTENT
import androidx.fragment.app.DialogFragment
import com.example.tmap_test.databinding.AddEditCapyDialogBinding

class AddEditCapybaraDialog(
    private val addCapyListener: AddCapyListener,
    private val capybaraItem: CapybaraItem? = null
) : DialogFragment() {
    companion object {
        val TAG = AddEditCapybaraDialog::class.java.simpleName
    }

    private var _binding: AddEditCapyDialogBinding? = null
    private val binding get() = _binding!!

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        _binding = AddEditCapyDialogBinding.inflate(inflater, container, false)

        return binding.root
    }

    override fun onStart() {
        super.onStart()
        dialog?.window?.setLayout(MATCH_PARENT, WRAP_CONTENT)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (capybaraItem != null) {
            binding.dialogTitle.text = getString(R.string.edit_capybara_title)
            binding.etNewName.setText(capybaraItem.name)
            binding.rgImages.check(getRadioButtonIdByImage(capybaraItem.imageId))
            binding.btnAddCapy.text = getString(R.string.btn_save)
        }

        binding.btnAddCapy.setOnClickListener {
            confirmNewCapy()
        }
    }

    private fun confirmNewCapy() {
        if (validateInput()) {
            addCapyListener.onCapybaraAddEdit(CapybaraItem(getNewName(), getImageId()), capybaraItem != null)
            dismiss()
        }
    }

    private fun validateInput(): Boolean {
        binding.ilNewName.error = null

        return if (getNewName().isEmpty()) {
            binding.ilNewName.error = getString(R.string.input_name_error)
            false
        } else true
    }

    private fun getNewName() = binding.etNewName.text.toString()

    private fun getImageId(): Int = when (binding.rgImages.checkedRadioButtonId) {
        R.id.rb_image1 -> R.drawable.image1
        R.id.rb_image2 -> R.drawable.image2
        else -> R.drawable.image3
    }

    private fun getRadioButtonIdByImage(capyImageId: Int) = when (capyImageId) {
        R.drawable.image1 -> R.id.rb_image1
        R.drawable.image2 -> R.id.rb_image2
        else -> R.id.rb_image3
    }
}