package com.example.tmap_test

import android.content.Context
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.tmap_test.Constants.Companion.SHARED_PREFS_NAME
import com.example.tmap_test.Constants.Companion.SHARED_PREFS_SHOW_SNACKBAR_KEY
import com.example.tmap_test.databinding.CapyListFragmentBinding
import com.google.android.material.snackbar.Snackbar

class CapyListFragment : Fragment(), AddCapyListener, CapybaraItemClickListener {
    companion object {
        private val TAG = CapyListFragment::class.java.simpleName
    }

    private lateinit var binding: CapyListFragmentBinding
    private lateinit var myAdapter: CapybarasAdapter

    private val data = mutableListOf<CapybaraItem>()
    private var editCapybaraItemIndex = -1

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = CapyListFragmentBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        myAdapter = CapybarasAdapter(requireContext(), data, this)
        setUpRecycler()

        binding.btnAdd.setOnClickListener {
            openAddEditDialog()
        }
    }

    override fun onCapybaraItemClick(capybaraItem: CapybaraItem) {
        editCapybaraItemIndex = data.indexOf(capybaraItem)
        openAddEditDialog(capybaraItem)
    }

    override fun onCapybaraAddEdit(capy: CapybaraItem, update: Boolean) {
        if (update) {
            data[editCapybaraItemIndex] = capy
            myAdapter.notifyItemChanged(editCapybaraItemIndex)
            rvScrollTo(editCapybaraItemIndex)
            editCapybaraItemIndex = -1
        } else {
            data.add(capy)
            myAdapter.notifyItemInserted(data.size - 1)
            rvScrollTo(data.size - 1)
            checkShowSnackBar()
        }
    }

    private fun rvScrollTo(position: Int) = binding.rv.scrollToPosition(position)

    private fun checkShowSnackBar() {
        val sharedPrefs = activity?.getSharedPreferences(SHARED_PREFS_NAME, Context.MODE_PRIVATE)
        val shouldShow = sharedPrefs?.getBoolean(SHARED_PREFS_SHOW_SNACKBAR_KEY, false) ?: false

        if (!shouldShow) return

        Snackbar.make(binding.root, getString(R.string.item_added), Snackbar.LENGTH_SHORT).show()
    }

    private fun setUpRecycler() {
        binding.rv.apply {
            adapter = myAdapter
            layoutManager = LinearLayoutManager(requireContext())
            setHasFixedSize(true)
        }
    }

    private fun openAddEditDialog(capybaraItem: CapybaraItem? = null) {
        val addCapyDialog = AddEditCapybaraDialog(this, capybaraItem)
        addCapyDialog.show(childFragmentManager, AddEditCapybaraDialog.TAG)
    }
}